Documentation
¶
Index ¶
- func IsScmNotFound(err error) bool
- type CreateRepository
- type EnvFactory
- func (o *EnvFactory) AddFlags(cmd *cobra.Command)
- func (o *EnvFactory) CreateDevEnvGitRepository(dir string, gitPublic bool) error
- func (o *EnvFactory) CreatePullRequest(dir string, gitURL string, kind string, branchName string, commitTitle string, ...) error
- func (o *EnvFactory) CreateScmClient(gitServer, owner, gitKind string) (*scm.Client, string, error)
- func (o *EnvFactory) GetInput() input.Interface
- func (o *EnvFactory) PrintBootJobInstructions(requirements *config.RequirementsConfig, link string) error
- func (o *EnvFactory) PushToGit(cloneURL string, userAuth *auth.UserAuth, dir string) error
- func (o *EnvFactory) VerifyPreInstall(disableVerifyPackages bool, dir string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsScmNotFound ¶
Types ¶
type CreateRepository ¶
type CreateRepository struct {
GitServer string
GitKind string
Owner string
Repository string
CurrentUsername string
GitPublic bool
}
func (*CreateRepository) ConfirmValues ¶
func (r *CreateRepository) ConfirmValues(i input.Interface, batch bool) error
ConfirmValues confirms to the user the values to be used to create the new git repository if using batch mode lets just validate the values are supplied or fail
func (*CreateRepository) CreateRepository ¶
func (r *CreateRepository) CreateRepository(scmClient *scm.Client) (*scm.Repository, error)
CreateRepository creates the git repository if it does not already exist
func (*CreateRepository) FullName ¶
func (r *CreateRepository) FullName() string
type EnvFactory ¶
type EnvFactory struct {
KubeClient kubernetes.Interface
JXClient versioned.Interface
Gitter gitclient.Interface
CommandRunner cmdrunner.CommandRunner
AuthConfigService auth.ConfigService
Input input.Interface
RepoName string
GitURLOutFile string
OutDir string
IOFileHandles *files.IOFileHandles
ScmClient *scm.Client
BatchMode bool
UseGitHubOAuth bool
CreatedRepository *CreateRepository
CreatedScmRepository *scm.Repository
UserAuth *auth.UserAuth
}
func (*EnvFactory) AddFlags ¶
func (o *EnvFactory) AddFlags(cmd *cobra.Command)
AddFlags adds common CLI flags
func (*EnvFactory) CreateDevEnvGitRepository ¶
func (o *EnvFactory) CreateDevEnvGitRepository(dir string, gitPublic bool) error
CreateDevEnvGitRepository creates the dev environment git repository from the given directory
func (*EnvFactory) CreatePullRequest ¶
func (o *EnvFactory) CreatePullRequest(dir string, gitURL string, kind string, branchName string, commitTitle string, commitBody string) error
CreatePullRequest crates a pull request if there are git changes
func (*EnvFactory) CreateScmClient ¶
CreateScmClient creates a new scm client
func (*EnvFactory) GetInput ¶
func (o *EnvFactory) GetInput() input.Interface
GetInput lazily creates the input interface
func (*EnvFactory) PrintBootJobInstructions ¶
func (o *EnvFactory) PrintBootJobInstructions(requirements *config.RequirementsConfig, link string) error
PrintBootJobInstructions prints the instructions to run the installer
func (*EnvFactory) VerifyPreInstall ¶
func (o *EnvFactory) VerifyPreInstall(disableVerifyPackages bool, dir string) error
VerifyPreInstall verify the pre install of boot
Click to show internal directories.
Click to hide internal directories.